@@ -8,7 +8,7 @@ adding some regexes test patterns.
  .. seealso: SerialConnection
 """
 import re
-from ve_utils.utils import UType
+from ve_utils.utype import UType
 
 __author__ = "Eli Serra"
 __copyright__ = "Copyright 2020, Eli Serra"
@@ -31,54 +31,60 @@ class SerialUtils (UType):
     def is_key_pattern(data: str) -> bool:
         """ Test if is valid key pattern """
         return SerialUtils.is_str(data)\
-            and SerialUtils.is_list_not_empty(
+            and SerialUtils.is_list(
             re.compile(
                 r"(?=\w{1,30}$)^([a-zA-Z\d]+(?:_[a-zA-Z\d]+)*)$"
-                ).findall(data)
+                ).findall(data),
+            not_null=True
         )
     
     @staticmethod
     def is_serial_key_pattern(data: str) -> bool:
         """ Test if is valid key pattern """
         return SerialUtils.is_str(data)\
-            and SerialUtils.is_list_not_empty(
+            and SerialUtils.is_list(
             re.compile(
                 r"(?=[a-zA-Z\d_#]{1,30}$)^([a-zA-Z\d#]+(?:_[a-zA-Z\d#]+)*)$"
-                ).findall(data)
+                ).findall(data),
+            not_null=True
         )
 
     @staticmethod
     def is_virtual_serial_port_pattern(data: str) -> bool:
         """ Test if is valid unix virtual serial port pattern """
-        return SerialUtils.is_str(data) and SerialUtils.is_list_not_empty(
+        return SerialUtils.is_str(data) and SerialUtils.is_list(
             re.compile(
                 r'^(vmodem\d{1,3})$'
-            ).findall(data)
+            ).findall(data),
+            not_null=True
         )
 
     @staticmethod
     def is_serial_port_name_pattern(data: str) -> bool:
         """ Test if is valid serial port name pattern """
-        return SerialUtils.is_str(data) and SerialUtils.is_list_not_empty(
+        return SerialUtils.is_str(data) and SerialUtils.is_list(
             re.compile(
                 r'^((?:tty(?:USB|ACM)|vmodem|COM)\d{1,3})$'
-            ).findall(data)
+            ).findall(data),
+            not_null=True
         )
 
     @staticmethod
     def is_unix_serial_port_pattern(data: str) -> bool:
         """ Test if is valid unix serial port pattern """
-        return SerialUtils.is_str(data) and SerialUtils.is_list_not_empty(
+        return SerialUtils.is_str(data) and SerialUtils.is_list(
             re.compile(
                 r'^(/dev/(tty(?:USB|ACM)\d{1,3}))$'
-                ).findall(data)
+                ).findall(data),
+            not_null=True
         )
     
     @staticmethod
     def is_win_serial_port_pattern(data: str) -> bool:
         """ Test if is valid win serial port pattern """
-        return SerialUtils.is_str(data) and SerialUtils.is_list_not_empty(
+        return SerialUtils.is_str(data) and SerialUtils.is_list(
             re.compile(
                 r'^(COM\d{1,3})$'
-                ).findall(data)
+                ).findall(data),
+            not_null=True
         )
