@@ -16,7 +16,7 @@ import logging
 import time
 import serial
 
-from ve_utils.utils import UType as Ut
+from ve_utils.utype import UType as Ut
 from vedirect_m8.sertest import SerialTestHelper
 from vedirect_m8.vedirect import Vedirect
 from vedirect_m8.serconnect import SerialConnection
@@ -99,7 +99,7 @@ class VedirectController(Vedirect):
         :param serial_test: The serial_test to execute to retrieve the serial port,
         :return: True if SerialTestHelper initialisation success.
         """
-        if Ut.is_dict_not_empty(serial_test):
+        if Ut.is_dict(serial_test, not_null=True):
             self._ser_test = SerialTestHelper(serial_test)
             if not self._ser_test.has_serial_tests():
                 raise SettingInvalidException(
@@ -167,7 +167,7 @@ class VedirectController(Vedirect):
             try:
                 res = dict()
                 data = self.read_data_single(timeout=1)
-                if Ut.is_dict_not_empty(data):
+                if Ut.is_dict(data, not_null=True):
                     res.update(data)
             except Exception as ex:
                 logger.debug(
@@ -195,7 +195,7 @@ class VedirectController(Vedirect):
         :doc-author: Trelent
         """
         if self.is_ready_to_search_ports():
-            if Ut.is_list_not_empty(ports):
+            if Ut.is_list(ports, not_null=True):
                 for port in ports:
                     if SerialConnection.is_serial_port(port):
 
@@ -313,14 +313,15 @@ class VedirectController(Vedirect):
                         ) as ex:
                     if self.wait_or_search_serial_connection(ex, connection_timeout):
                         now = tim = time.time()
+                        packet = self.get_serial_packet()
 
                 if packet is not None:
                     logger.debug(
                         "Serial reader success: "
-                        "byte: %s -- packet: %s -- "
-                        "dict: %s -- state: %s -- "
+                        "packet: %s -- "
+                        "state: %s -- "
                         "bytes_sum: %s " % 
-                        (byte, packet, self.dict, self.state, self.bytes_sum)
+                        (packet, self.state, self.bytes_sum)
                     )
                     callback_func(packet)
                     now = tim
@@ -330,9 +331,9 @@ class VedirectController(Vedirect):
                 # timeout serial read
                 Vedirect.is_timeout(tim - now, timeout)
 
-                if Ut.is_int(max_loops) and i > max_loops:
+                if Ut.is_int(max_loops) and i >= max_loops:
                     return True
-                time.sleep(0.95)
+                time.sleep(0.1)
         else:
             logger.error(
                 '[VeDirect::read_data_callback] '
